FCO REST client
===============

This repository contains minimalistic python client for FCO REST API, together
with command line client.


Quickstart
----------

At the moment, documentation is non existent, so the best way of learning to
use the tool is to experiment. Command line tool is configured to print help
messages on bad invocations, so you can safely execute any command without
risking doing any damage.
